==> nextcloud-18.0.4.tgz: nextcloud/apps/comments/l10n/tr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Yorumlar",
    "You commented" : "Yorum yaptınız",
    "%1$s commented" : "%1$s yorumlanmış",
    "{author} commented" : "{author} yorum yaptı",
    "You commented on %1$s" : "%1$s hakkında yorum yaptınız",
    "You commented on {file}" : "{file} hakkında yorum yaptınız",
    "%1$s commented on %2$s" : "%1$s, %2$s için yorum yaptı",
    "{author} commented on {file}" : "{author}, {file} hakkında yorum yaptı",
    "<strong>Comments</strong> for files" : "Dosyalar için <strong>yorumlar</strong>",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "“{file}” hakkında bir yorumda silinmiş bir kullanıcı tarafından anıldınız",
    "{user} mentioned you in a comment on “{file}”" : "{user}, “{file}” hakkındaki bir yorumda sizi andı",
    "Files app plugin to add comments to files" : "Dosyalara notlar eklenmesini sağlayan dosyalar uygulaması eki",
    "Edit comment" : "Yorumu düzenle",
    "Delete comment" : "Yorumu sil",
    "New comment …" : "Yorum ekle …",
    "Post" : "Gönder",
    "Cancel" : "İptal",
    "[Deleted user]" : "[Silinmiş kullanıcı]",
    "No comments yet, start the conversation!" : "Henüz bir yorum yapılmamış! Bir görüşme başlatın!",
    "More comments …" : "Diğer yorumlar …",
    "Save" : "Kaydet",
    "Allowed characters {count} of {max}" : "Yazılabilecek karakter sayısı {count}/{max}",
    "Error occurred while retrieving comment with ID {id}" : "{id} kodlu yorum alınırken sorun çıktı",
    "Error occurred while updating comment with id {id}" : "{id} kodlu yorum güncellenirken sorun çıktı",
    "Error occurred while posting comment" : "Yorum gönderilirken sorun çıktı",
    "_%n unread comment_::_%n unread comments_" : ["%n okunmamış yorum","%n okunmamış yorum"],
    "_1 new comment_::_{unread} new comments_" : ["1 yeni yorum","{unread} yeni yorum"],
    "Comment" : "Yorum"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-21.0.2.tgz: nextcloud/apps/comments/l10n/tr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Yorumlar",
    "You commented" : "Yorum yaptınız",
    "%1$s commented" : "%1$s yorumlanmış",
    "{author} commented" : "{author} yorum yaptı",
    "You commented on %1$s" : "%1$s hakkında yorum yaptınız",
    "You commented on {file}" : "{file} hakkında yorum yaptınız",
    "%1$s commented on %2$s" : "%1$s, %2$s için yorum yaptı",
    "{author} commented on {file}" : "{author}, {file} hakkında yorum yaptı",
    "<strong>Comments</strong> for files" : "Dosyalar için <strong>yorumlar</strong>",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "“{file}” hakkında bir yorumda silinmiş bir kullanıcı tarafından anıldınız",
    "{user} mentioned you in a comment on “{file}”" : "{user}, “{file}” hakkındaki bir yorumda sizi andı",
    "Files app plugin to add comments to files" : "Dosyalara notlar eklenmesini sağlayan dosyalar uygulaması eki",
    "Edit comment" : "Yorumu düzenle",
    "Delete comment" : "Yorumu sil",
    "Cancel edit" : "Düzenlemeyi iptal et",
    "Post comment" : "Yorum gönder",
    "No comments yet, start the conversation!" : "Henüz bir yorum yapılmamış! Bir görüşme başlatın!",
    "No more messages" : "Başka ileti yok",
    "Retry" : "Yeniden dene",
    "Unable to load the comments list" : "Yorum listesi yüklenemedi",
    "_%n unread comment_::_%n unread comments_" : ["%n okunmamış yorum","%n okunmamış yorum"],
    "_1 new comment_::_{unread} new comments_" : ["1 yeni yorum","{unread} yeni yorum"],
    "Comment" : "Yorum",
    "An error occurred while trying to edit the comment" : "Yorum düzenlenmeye çalışılırken bir sorun çıktı",
    "Comment deleted" : "Yorum silindi",
    "An error occurred while trying to delete the comment" : "Yorum silinmeye çalışılırken bir sorun çıktı",
    "An error occurred while trying to create the comment" : "Yorum eklenmeye çalışılırken bir sorun çıktı",
    "New comment …" : "Yorum ekle …",
    "Post" : "Gönder",
    "Cancel" : "İptal",
    "[Deleted user]" : "[Silinmiş kullanıcı]",
    "More comments …" : "Diğer yorumlar …",
    "Save" : "Kaydet",
    "Allowed characters {count} of {max}" : "Yazılabilecek karakter sayısı {count}/{max}",
    "Error occurred while retrieving comment with ID {id}" : "{id} kodlu yorum alınırken sorun çıktı",
    "Error occurred while updating comment with id {id}" : "{id} kodlu yorum güncellenirken sorun çıktı",
    "Error occurred while posting comment" : "Yorum gönderilirken sorun çıktı"
},
"nplurals=2; plural=(n > 1);");
